HeapDump

Struct HeapDump 

pub struct HeapDump { /* private fields */ }
Available on crate feature luau only.
Represents a heap dump of a Luau memory state.

Implementations

Source

impl HeapDump

pub fn size(&self) -> u64

Returns the total size of the Lua heap in bytes.

pub fn size_by_type<'a>( &'a self, category: Option<&str>, ) -> HashMap<&'a str, (usize, u64)>

Returns a mapping from object type to (count, total size in bytes).

If category is provided, only objects in that category are considered. An unknown category yields an empty map.

pub fn size_by_category(&self) -> HashMap<&str, u64>

Returns a mapping from category name to total size in bytes.

pub fn size_by_userdata<'a>( &'a self, category: Option<&str>, ) -> HashMap<&'a str, (usize, u64)>

Returns a mapping from userdata type to (count, total size in bytes).

If category is provided, only objects in that category are considered. An unknown category yields an empty map.