pub struct HeapDump { /* private fields */ }Available on crate feature
luau only.Expand description
Represents a heap dump of a Luau memory state.
Implementations
Sourceimpl HeapDump
impl HeapDump
Sourcepub fn size_by_type<'a>(
&'a self,
category: Option<&str>,
) -> HashMap<&'a str, (usize, u64)>
pub fn size_by_type<'a>( &'a self, category: Option<&str>, ) -> HashMap<&'a str, (usize, u64)>
Returns a mapping from object type to (count, total size in bytes).
If category is provided, only objects in that category are considered.
Sourcepub fn size_by_category(&self) -> HashMap<&str, u64>
pub fn size_by_category(&self) -> HashMap<&str, u64>
Returns a mapping from category name to total size in bytes.